@@ -473,14 +473,12 @@ default.plot.manyglm  <- function(x, which = 1, res.type="pit.norm", caption = c
       
       # The normal QQ plot
       if (show[2]) { 
-         rs.is.zero <- rs < (1e-9)
+#         rs.is.zero <- rs < (1e-9) #DW, 23/10/14: this seems to be an error - why would r near zero be a problem?
          rstmp <- c(rs)
-	 rsn0 <- rstmp[!rs.is.zero]
-         ylim <- range(rsn0, na.rm = TRUE)
-	 ylim[2] <- ylim[2] + diff(ylim) * 0.075	 
-   	 qq <- do.call( "qqnorm", c(list(rsn0, main = main, ylab = ylab23, ylim=ylim, col=color, asp=1, cex.lab=1.5, cex=1.5, cex.axis=1.5, cex.main=1.5, lwd=2), dots))
-    
-	 if (qqline) qqline(rsn0, lty = 3, col = "gray50", lwd=2)          
+         ylim <- range(max(abs(rstmp))*c(-1,1), na.rm = TRUE) #DW, 23/10/14: to make ylims symmetric about zero
+#	 ylim[2] <- ylim[2] + diff(ylim) * 0.075 #DW, 23/10/14: I don't see any point for this line
+   	 qq <- do.call( "qqnorm", c(list(rstmp, main = main, ylab = ylab23, ylim=ylim, col=color, asp=1, cex.lab=1.5, cex=1.5, cex.axis=1.5, cex.main=1.5, lwd=2), dots))
+	 if (qqline) qqline(rstmp, lty = 3, col = "gray50", lwd=2)          
          # Use vector built of transposed x bzw y in order to plot
 	 # in the right colors.
 	 if (one.fig) do.call( "title", c(list(sub = sub.caption), dots))
@@ -495,7 +493,6 @@ default.plot.manyglm  <- function(x, which = 1, res.type="pit.norm", caption = c
 	     legend(legend.pos, legend=leg, col=color, pch=1, ncol=ncoll, cex=cexl-0.1,inset=-0.35,xpd=NA, x.intersp=0.5, lwd=2, lty=0)  
 	 }
       }
-
       # The scale vs. location plot
       if (show[3]) {
           sqrtabsr <- c(sqrt(abs(rs)))
